from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .secret_version_info import SecretVersionInfo

@dataclass
class SecretVersionsMetadata(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The currentVersion property
    current_version: Optional[int] = None
    # The maxVersions property
    max_versions: Optional[int] = None
    # The oldestVersion property
    oldest_version: Optional[int] = None
    # The versions property
    versions: Optional[list[SecretVersionInfo]] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SecretVersionsMetadata:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SecretVersionsMetadata
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SecretVersionsMetadata()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .secret_version_info import SecretVersionInfo

        from .secret_version_info import SecretVersionInfo

        fields: dict[str, Callable[[Any], None]] = {
            "currentVersion": lambda n : setattr(self, 'current_version', n.get_int_value()),
            "maxVersions": lambda n : setattr(self, 'max_versions', n.get_int_value()),
            "oldestVersion": lambda n : setattr(self, 'oldest_version', n.get_int_value()),
            "versions": lambda n : setattr(self, 'versions', n.get_collection_of_object_values(SecretVersionInfo)),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_int_value("currentVersion", self.current_version)
        writer.write_int_value("maxVersions", self.max_versions)
        writer.write_int_value("oldestVersion", self.oldest_version)
        writer.write_collection_of_object_values("versions", self.versions)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .envelope import Envelope

@dataclass
class DeadLetterEnvelope(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The envelope property
    envelope: Optional[Envelope] = None
    # The exceptionMessage property
    exception_message: Optional[str] = None
    # The exceptionType property
    exception_type: Optional[str] = None
    # The executionTime property
    execution_time: Optional[datetime.datetime] = None
    # The id property
    id: Optional[UUID] = None
    # The messageType property
    message_type: Optional[str] = None
    # The receivedAt property
    received_at: Optional[str] = None
    # The replayable property
    replayable: Optional[bool] = None
    # The sentAt property
    sent_at: Optional[datetime.datetime] = None
    # The source property
    source: Optional[str] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DeadLetterEnvelope:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DeadLetterEnvelope
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DeadLetterEnvelope()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .envelope import Envelope

        from .envelope import Envelope

        fields: dict[str, Callable[[Any], None]] = {
            "envelope": lambda n : setattr(self, 'envelope', n.get_object_value(Envelope)),
            "exceptionMessage": lambda n : setattr(self, 'exception_message', n.get_str_value()),
            "exceptionType": lambda n : setattr(self, 'exception_type', n.get_str_value()),
            "executionTime": lambda n : setattr(self, 'execution_time', n.get_datetime_value()),
            "id": lambda n : setattr(self, 'id', n.get_uuid_value()),
            "messageType": lambda n : setattr(self, 'message_type', n.get_str_value()),
            "receivedAt": lambda n : setattr(self, 'received_at', n.get_str_value()),
            "replayable": lambda n : setattr(self, 'replayable', n.get_bool_value()),
            "sentAt": lambda n : setattr(self, 'sent_at', n.get_datetime_value()),
            "source": lambda n : setattr(self, 'source', n.get_str_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_object_value("envelope", self.envelope)
        writer.write_str_value("exceptionMessage", self.exception_message)
        writer.write_str_value("exceptionType", self.exception_type)
        writer.write_datetime_value("executionTime", self.execution_time)
        writer.write_uuid_value("id", self.id)
        writer.write_str_value("messageType", self.message_type)
        writer.write_str_value("receivedAt", self.received_at)
        writer.write_bool_value("replayable", self.replayable)
        writer.write_datetime_value("sentAt", self.sent_at)
        writer.write_str_value("source", self.source)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union
from uuid import UUID

if TYPE_CHECKING:
    from .envelope_headers import Envelope_headers

@dataclass
class Envelope(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The acceptedContentTypes property
    accepted_content_types: Optional[list[str]] = None
    # The ackRequested property
    ack_requested: Optional[bool] = None
    # The attempts property
    attempts: Optional[int] = None
    # The contentType property
    content_type: Optional[str] = None
    # The conversationId property
    conversation_id: Optional[UUID] = None
    # The correlationId property
    correlation_id: Optional[str] = None
    # The data property
    data: Optional[bytes] = None
    # The deduplicationId property
    deduplication_id: Optional[str] = None
    # The deliverBy property
    deliver_by: Optional[datetime.datetime] = None
    # The destination property
    destination: Optional[str] = None
    # The endpointName property
    endpoint_name: Optional[str] = None
    # The groupId property
    group_id: Optional[str] = None
    # The headers property
    headers: Optional[Envelope_headers] = None
    # The id property
    id: Optional[UUID] = None
    # The keepUntil property
    keep_until: Optional[datetime.datetime] = None
    # The messageType property
    message_type: Optional[str] = None
    # The offset property
    offset: Optional[int] = None
    # The parentId property
    parent_id: Optional[str] = None
    # The partitionKey property
    partition_key: Optional[str] = None
    # The replyRequested property
    reply_requested: Optional[str] = None
    # The replyUri property
    reply_uri: Optional[str] = None
    # The sagaId property
    saga_id: Optional[str] = None
    # The scheduleDelay property
    schedule_delay: Optional[str] = None
    # The scheduledTime property
    scheduled_time: Optional[datetime.datetime] = None
    # The sendAttempts property
    send_attempts: Optional[int] = None
    # The sentAt property
    sent_at: Optional[datetime.datetime] = None
    # The source property
    source: Optional[str] = None
    # The tenantId property
    tenant_id: Optional[str] = None
    # The topicName property
    topic_name: Optional[str] = None
    # The userName property
    user_name: Optional[str] = None
    # The wasPersistedInOutbox property
    was_persisted_in_outbox: Optional[bool] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> Envelope:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: Envelope
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return Envelope()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .envelope_headers import Envelope_headers

        from .envelope_headers import Envelope_headers

        fields: dict[str, Callable[[Any], None]] = {
            "acceptedContentTypes": lambda n : setattr(self, 'accepted_content_types', n.get_collection_of_primitive_values(str)),
            "ackRequested": lambda n : setattr(self, 'ack_requested', n.get_bool_value()),
            "attempts": lambda n : setattr(self, 'attempts', n.get_int_value()),
            "contentType": lambda n : setattr(self, 'content_type', n.get_str_value()),
            "conversationId": lambda n : setattr(self, 'conversation_id', n.get_uuid_value()),
            "correlationId": lambda n : setattr(self, 'correlation_id', n.get_str_value()),
            "data": lambda n : setattr(self, 'data', n.get_bytes_value()),
            "deduplicationId": lambda n : setattr(self, 'deduplication_id', n.get_str_value()),
            "deliverBy": lambda n : setattr(self, 'deliver_by', n.get_datetime_value()),
            "destination": lambda n : setattr(self, 'destination', n.get_str_value()),
            "endpointName": lambda n : setattr(self, 'endpoint_name', n.get_str_value()),
            "groupId": lambda n : setattr(self, 'group_id', n.get_str_value()),
            "headers": lambda n : setattr(self, 'headers', n.get_object_value(Envelope_headers)),
            "id": lambda n : setattr(self, 'id', n.get_uuid_value()),
            "keepUntil": lambda n : setattr(self, 'keep_until', n.get_datetime_value()),
            "messageType": lambda n : setattr(self, 'message_type', n.get_str_value()),
            "offset": lambda n : setattr(self, 'offset', n.get_int_value()),
            "parentId": lambda n : setattr(self, 'parent_id', n.get_str_value()),
            "partitionKey": lambda n : setattr(self, 'partition_key', n.get_str_value()),
            "replyRequested": lambda n : setattr(self, 'reply_requested', n.get_str_value()),
            "replyUri": lambda n : setattr(self, 'reply_uri', n.get_str_value()),
            "sagaId": lambda n : setattr(self, 'saga_id', n.get_str_value()),
            "scheduleDelay": lambda n : setattr(self, 'schedule_delay', n.get_str_value()),
            "scheduledTime": lambda n : setattr(self, 'scheduled_time', n.get_datetime_value()),
            "sendAttempts": lambda n : setattr(self, 'send_attempts', n.get_int_value()),
            "sentAt": lambda n : setattr(self, 'sent_at', n.get_datetime_value()),
            "source": lambda n : setattr(self, 'source', n.get_str_value()),
            "tenantId": lambda n : setattr(self, 'tenant_id', n.get_str_value()),
            "topicName": lambda n : setattr(self, 'topic_name', n.get_str_value()),
            "userName": lambda n : setattr(self, 'user_name', n.get_str_value()),
            "wasPersistedInOutbox": lambda n : setattr(self, 'was_persisted_in_outbox', n.get_bool_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_collection_of_primitive_values("acceptedContentTypes", self.accepted_content_types)
        writer.write_bool_value("ackRequested", self.ack_requested)
        writer.write_int_value("attempts", self.attempts)
        writer.write_str_value("contentType", self.content_type)
        writer.write_uuid_value("conversationId", self.conversation_id)
        writer.write_str_value("correlationId", self.correlation_id)
        writer.write_bytes_value("data", self.data)
        writer.write_str_value("deduplicationId", self.deduplication_id)
        writer.write_datetime_value("deliverBy", self.deliver_by)
        writer.write_str_value("destination", self.destination)
        writer.write_str_value("endpointName", self.endpoint_name)
        writer.write_str_value("groupId", self.group_id)
        writer.write_object_value("headers", self.headers)
        writer.write_uuid_value("id", self.id)
        writer.write_datetime_value("keepUntil", self.keep_until)
        writer.write_str_value("messageType", self.message_type)
        writer.write_int_value("offset", self.offset)
        writer.write_str_value("parentId", self.parent_id)
        writer.write_str_value("partitionKey", self.partition_key)
        writer.write_str_value("replyRequested", self.reply_requested)
        writer.write_str_value("replyUri", self.reply_uri)
        writer.write_str_value("sagaId", self.saga_id)
        writer.write_str_value("scheduleDelay", self.schedule_delay)
        writer.write_datetime_value("scheduledTime", self.scheduled_time)
        writer.write_int_value("sendAttempts", self.send_attempts)
        writer.write_datetime_value("sentAt", self.sent_at)
        writer.write_str_value("source", self.source)
        writer.write_str_value("tenantId", self.tenant_id)
        writer.write_str_value("topicName", self.topic_name)
        writer.write_str_value("userName", self.user_name)
        writer.write_bool_value("wasPersistedInOutbox", self.was_persisted_in_outbox)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import ComposedTypeWrapper, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

if TYPE_CHECKING:
    from .environment_operation_response_environment_member1 import EnvironmentOperationResponse_environmentMember1
    from .environment_response import EnvironmentResponse

@dataclass
class EnvironmentOperationResponse_environment(ComposedTypeWrapper, Parsable):
    """
    Composed type wrapper for classes EnvironmentOperationResponse_environmentMember1, EnvironmentResponse
    """
    # Composed type representation for type EnvironmentOperationResponse_environmentMember1
    environment_operation_response_environment_member1: Optional[EnvironmentOperationResponse_environmentMember1] = None
    # Composed type representation for type EnvironmentResponse
    environment_response: Optional[EnvironmentResponse] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> EnvironmentOperationResponse_environment:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: EnvironmentOperationResponse_environment
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        try:
            child_node = parse_node.get_child_node("")
            mapping_value = child_node.get_str_value() if child_node else None
        except AttributeError:
            mapping_value = None
        result = EnvironmentOperationResponse_environment()
        if mapping_value and mapping_value.casefold() == "".casefold():
            from .environment_operation_response_environment_member1 import EnvironmentOperationResponse_environmentMember1

            result.environment_operation_response_environment_member1 = EnvironmentOperationResponse_environmentMember1()
        elif mapping_value and mapping_value.casefold() == "EnvironmentResponse".casefold():
            from .environment_response import EnvironmentResponse

            result.environment_response = EnvironmentResponse()
        return result
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        from .environment_operation_response_environment_member1 import EnvironmentOperationResponse_environmentMember1
        from .environment_response import EnvironmentResponse

        if self.environment_operation_response_environment_member1:
            return self.environment_operation_response_environment_member1.get_field_deserializers()
        if self.environment_response:
            return self.environment_response.get_field_deserializers()
        return {}
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        if self.environment_operation_response_environment_member1:
            writer.write_object_value(None, self.environment_operation_response_environment_member1)
        elif self.environment_response:
            writer.write_object_value(None, self.environment_response)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class SecretVersionInfo(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The createdAt property
    created_at: Optional[datetime.datetime] = None
    # The deletedAt property
    deleted_at: Optional[datetime.datetime] = None
    # The isCurrent property
    is_current: Optional[bool] = None
    # The isDestroyed property
    is_destroyed: Optional[bool] = None
    # The version property
    version: Optional[int] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> SecretVersionInfo:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: SecretVersionInfo
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return SecretVersionInfo()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "createdAt": lambda n : setattr(self, 'created_at', n.get_datetime_value()),
            "deletedAt": lambda n : setattr(self, 'deleted_at', n.get_datetime_value()),
            "isCurrent": lambda n : setattr(self, 'is_current', n.get_bool_value()),
            "isDestroyed": lambda n : setattr(self, 'is_destroyed', n.get_bool_value()),
            "version": lambda n : setattr(self, 'version', n.get_int_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_datetime_value("createdAt", self.created_at)
        writer.write_datetime_value("deletedAt", self.deleted_at)
        writer.write_bool_value("isCurrent", self.is_current)
        writer.write_bool_value("isDestroyed", self.is_destroyed)
        writer.write_int_value("version", self.version)
        writer.write_additional_data_value(self.additional_data)
    




from __future__ import annotations
import datetime
from collections.abc import Callable
from dataclasses import dataclass, field
from kiota_abstractions.serialization import AdditionalDataHolder, Parsable, ParseNode, SerializationWriter
from typing import Any, Optional, TYPE_CHECKING, Union

@dataclass
class DeadLetterEnvelopeGetRequest(AdditionalDataHolder, Parsable):
    # Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
    additional_data: dict[str, Any] = field(default_factory=dict)

    # The databaseUri property
    database_uri: Optional[str] = None
    # The exceptionMessage property
    exception_message: Optional[str] = None
    # The exceptionType property
    exception_type: Optional[str] = None
    # The from property
    from_: Optional[datetime.datetime] = None
    # The limit property
    limit: Optional[int] = None
    # The messageType property
    message_type: Optional[str] = None
    # The pageNumber property
    page_number: Optional[int] = None
    # The tenantId property
    tenant_id: Optional[str] = None
    # The until property
    until: Optional[datetime.datetime] = None
    
    @staticmethod
    def create_from_discriminator_value(parse_node: ParseNode) -> DeadLetterEnvelopeGetRequest:
        """
        Creates a new instance of the appropriate class based on discriminator value
        param parse_node: The parse node to use to read the discriminator value and create the object
        Returns: DeadLetterEnvelopeGetRequest
        """
        if parse_node is None:
            raise TypeError("parse_node cannot be null.")
        return DeadLetterEnvelopeGetRequest()
    
    def get_field_deserializers(self,) -> dict[str, Callable[[ParseNode], None]]:
        """
        The deserialization information for the current model
        Returns: dict[str, Callable[[ParseNode], None]]
        """
        fields: dict[str, Callable[[Any], None]] = {
            "databaseUri": lambda n : setattr(self, 'database_uri', n.get_str_value()),
            "exceptionMessage": lambda n : setattr(self, 'exception_message', n.get_str_value()),
            "exceptionType": lambda n : setattr(self, 'exception_type', n.get_str_value()),
            "from": lambda n : setattr(self, 'from_', n.get_datetime_value()),
            "limit": lambda n : setattr(self, 'limit', n.get_int_value()),
            "messageType": lambda n : setattr(self, 'message_type', n.get_str_value()),
            "pageNumber": lambda n : setattr(self, 'page_number', n.get_int_value()),
            "tenantId": lambda n : setattr(self, 'tenant_id', n.get_str_value()),
            "until": lambda n : setattr(self, 'until', n.get_datetime_value()),
        }
        return fields
    
    def serialize(self,writer: SerializationWriter) -> None:
        """
        Serializes information the current object
        param writer: Serialization writer to use to serialize this model
        Returns: None
        """
        if writer is None:
            raise TypeError("writer cannot be null.")
        writer.write_str_value("databaseUri", self.database_uri)
        writer.write_str_value("exceptionMessage", self.exception_message)
        writer.write_str_value("exceptionType", self.exception_type)
        writer.write_datetime_value("from", self.from_)
        writer.write_int_value("limit", self.limit)
        writer.write_str_value("messageType", self.message_type)
        writer.write_int_value("pageNumber", self.page_number)
        writer.write_str_value("tenantId", self.tenant_id)
        writer.write_datetime_value("until", self.until)
        writer.write_additional_data_value(self.additional_data)
    

